<?php

namespace Modules\OpcData\Http\Controllers\Api\zaoquan;

use App\Http\Controllers\Api\BaseController;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Modules\OpcData\Services\zaoquan\ZQDcsApiService;

/**
 * 枣泉自动化——东井通风
 */
class ZQDcsWorkFaceController  extends BaseController
{

    private $db_name='etl_zaoquan';

    protected $apiService;
    protected $apiUrl = 'http://7.250.4.3:4300/v1/common/GetPointRealDataByPageV3';

    public function __construct(ZQDcsApiService $apiService)
    {
        parent::__construct();
        $this->apiService = $apiService;
    }

    public function getList(Request $request) {
        $sysCode = isset($request->sys_code) ? $request->sys_code : null;     // 矿分类
        if ($sysCode == null) {
            $msg="参数为空";
            $code=-1;
            return $this->error($code, $msg);
        } else {
            switch ($sysCode) {
                case '220707gzm': // 220707工作面
                    return $this->get220707GzmList();
                case 'rhb': // 乳化泵
                    return $this->getRhbList();
                case 'cmj': // 采煤机
                    return $this->getCmjList();
                case 'sj': // 三机
                    return $this->getSjList();
                default:
                    $msg="未知数据";
                    $code=-2;
                    return $this->error($code, $msg);
            }
        }
    }

    /*
     * 220707工作面
     * */
    public function get220707GzmList() {

        $keys=[
            "2045462760791041_1", "2045462763287553_1", "2045462765548545_1", // 1\2\3号乳化泵运行状态
            "2045462780937217_1", // 增压泵状态
            "2045462760676353_1", "2045462763166721_1", // 1、2清水泵状态
            "2045462760600577_1", "2045462763088897_1", // 1、2号清水泵油温
            "2045462760713217_1","2045462763203585_1","2045462765470721_1", // 1、2、3号乳化泵油温
            "2045462780849153_1", // 乳化泵油温
            "2045462774410241_1", "2045462774860801_1","2045462780767233_1","2045462774537217_1", // 牵引速度、俯仰角、倾角、瓦斯浓度
            "2045462780728321_1","2045462777420801_1","2045462781619201_1", // 破碎机、刮板机运行状态、转载机电流
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];

        $info = [
            "info"=>[
                [
                    "label"=> "设计可采长度",
                    "value"=> "2159M"
                ],
                [
                    "label"=> "开采煤层",
                    "value"=> "7"
                ],
                [
                    "label"=> "面积",
                    "value"=> "450301㎡"
                ],
                [
                    "label"=> "煤层总厚",
                    "value"=> "3.9M"
                ],
                [
                    "label"=> "工作面采高",
                    "value"=> "2.6M"
                ],
                [
                    "label"=> "支架数目",
                    "value"=> "128"
                ],
                [
                    "label"=> "循环刀数",
                    "value"=> "9"
                ],
                [
                    "label"=> "回踩日期",
                    "value"=> "2023.2"
                ]
            ],
            "ruhuabeng"=>[
                [
                    "label"=>"1#液泵",
                    "state"=>($baseData['2045462760791041_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462760791041_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"乳化增压泵",
                    "state"=>($baseData['2045462780937217_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462780937217_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"2#液泵",
                    "state"=>($baseData['2045462763287553_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462763287553_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"1#水泵",
                    "state"=>($baseData['2045462760676353_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462760676353_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"3#液泵",
                    "state"=>($baseData['2045462765548545_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462765548545_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"2#水泵",
                    "state"=>($baseData['2045462763166721_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462763166721_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
            ],
            "caimeiji"=>[
                "state"=>0,
                "data"=>[
                    [
                        "label"=>"牵引速度",
                        "value"=>($baseData['2045462774410241_1'] ?? 0)."m/min",
                    ],
                    [
                        "label"=>"俯仰角",
                        "value"=>($baseData['2045462774860801_1'] ?? 0)."°",
                    ],
                    [
                        "label"=>"瓦斯浓度",
                        "value"=>($baseData['2045462774537217_1'] ?? 0)."%",
                    ],
                    [
                        "label"=>"倾角",
                        "value"=>($baseData['2045462780767233_1'] ?? 0)."°",
                    ],
                ]
            ],
            "sanji"=>[
                [
                    "label"=>"转载机运行状态",
                    "state"=>($baseData['2045462780728321_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462780728321_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"破碎机运行状态",
                    "state"=>($baseData['2045462777420801_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462777420801_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
                [
                    "label"=>"刮板机运行状态",
                    "state"=>($baseData['2045462781619201_1'] ?? 0) > 0 ? 1 : 0,
                    "text"=>($baseData['2045462781619201_1'] ?? 0) > 0 ? "启动" : "停止",
                ],
            ]
        ];

        return json_encode($info);
    }

    /*
     * 乳化泵
     * */
    public function getRhbList() {

        $keys=[
            "2045462760791041_1", // "枣泉煤矿220707工作面_1号乳化泵运行状态"
            "2045462763287553_1", // "枣泉煤矿220707工作面_2号乳化泵运行状态"
            "2045462765548545_1", // "枣泉煤矿220707工作面_3号乳化泵运行状态"

            "2045462780937217_1", // "枣泉煤矿220707工作面_乳化泵压泵运行状态"

            "2045462760676353_1", // "枣泉煤矿220707工作面_1号清水泵运行状态"
            "2045462763166721_1", // "枣泉煤矿220707工作面_2号清水泵运行状态"

            "2045462760713217_1", // "枣泉煤矿220707工作面_1号乳化泵润滑油温"
            "2045462760752129_1", // "枣泉煤矿220707工作面_1号乳化泵润滑油压"
            "2045462763203585_1", // "枣泉煤矿220707工作面_2号乳化泵润滑油温"
            "2045462763250689_1", // "枣泉煤矿220707工作面_2号乳化泵润滑油压"
            "2045462765470721_1", // "枣泉煤矿220707工作面_3号乳化泵润滑油温"
            "2045462765509633_1", // "枣泉煤矿220707工作面_3号乳化泵润滑油压"
            "2045462760600577_1", // "枣泉煤矿220707工作面_1号清水泵润滑油温"
            "2045462760637441_1", // "枣泉煤矿220707工作面_1号清水泵润滑油压"
            "2045462763088897_1", // "枣泉煤矿220707工作面_2号清水泵润滑油温"
            "2045462763127809_1", // "枣泉煤矿220707工作面_2号清水泵润滑油压"

            "2045462780849153_1", // "枣泉煤矿220707工作面_乳化泵压泵润滑油温"
            "2045462780896257_1", // "枣泉煤矿220707工作面_乳化泵压泵润滑油压"
            "2045462780808193_1", // "枣泉煤矿220707工作面_乳化泵系统压力"
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "info"=>[
                [
                    "label"=> "1#乳化泵",
                    "state"=> ($baseData['2045462760791041_1'] ?? 0),
                    "text"=>($baseData['2045462760791041_1'] ?? 0) > 0 ? "启动" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2045462760713217_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2045462760752129_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "2#乳化泵",
                    "state"=> ($baseData['2045462763287553_1'] ?? 0),
                    "text"=>($baseData['2045462763287553_1'] ?? 0) > 0 ? "启动" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2045462763203585_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2045462763250689_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "3#乳化泵",
                    "state"=> ($baseData['2045462765548545_1'] ?? 0),
                    "text"=>($baseData['2045462765548545_1'] ?? 0) > 0 ? "启动" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2045462765470721_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2045462765509633_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "乳化增压泵",
                    "state"=> ($baseData['2045462780937217_1'] ?? 0),
                    "text"=>($baseData['2045462780937217_1'] ?? 0) > 0 ? "启动" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2045462780849153_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2045462780896257_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "1#清水泵",
                    "state"=> ($baseData['2045462760676353_1'] ?? 0),
                    "text"=>($baseData['2045462760676353_1'] ?? 0) > 0 ? "启动" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2045462760600577_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2045462760637441_1'] ?? 0),
                        ]
                    ]
                ],
                [
                    "label"=> "2#清水泵",
                    "state"=> ($baseData['2045462763166721_1'] ?? 0),
                    "text"=>($baseData['2045462763166721_1'] ?? 0) > 0 ? "启动" : "停止",
                    "info"=>[
                        [
                            "label"=>"润滑油温（℃）",
                            "value"=>($baseData['2045462763088897_1'] ?? 0),
                        ],
                        [
                            "label"=>"润滑油压（Mpa）",
                            "value"=>($baseData['2045462763127809_1'] ?? 0),
                        ]
                    ]
                ],
            ],
            "chartData_1"=>[
                "categories"=>[
                    "00:00", "00:00","00:00","00:00","00:00","00:00",
                ],
                "series"=>[
                    [
                        "name"=>"位置",
                        "data"=>[0, 0, 0, 0, 0, 0]
                    ]
                ]
            ]
        ];

        return json_encode($info);
    }

    /*
     * 采煤机
     * */
    public function getCmjList() {

        $keys=[
            "2045462774273025_1", //"采煤机回路启停状态"
            "2045462780728321_1", //"破碎机运行状态"
            "2045462782241793_1", //"转载机运行状态"
            "2045462782626817_1", //"纵撕报警"
            "2045462781230081_1", //"烟雾报警"
            "2045462774578177_1", //"堆煤报警"
            "2045462781189121_1", // 通讯状态
            "2045462760791041_1", //"1号乳化泵运行状态"
            "2045462763287553_1", //"2号乳化泵运行状态"
            "2045462765548545_1", //"3号乳化泵运行状态"
            "2045462760676353_1", //"1号清水泵运行状态"
            "2045462763166721_1", //"2号清水泵运行状态"
            "2045462777732097_1", //"煤机位置"
            "2045462774410241_1", //"采煤机牵引速度"
            "2045462780767233_1", //"倾角"
            "2045462774860801_1", //"俯仰角"
            "2010296279116801_1", //"22采区220707回风巷15米"
            "2010796280116225_1", //"22采区220707回风巷80米"
            "2019138663484417_1", //"22采区220707机巷110米"
            "2019139795078145_1", //"22采区220707机巷1250米"

            "2045462782794753_1", //"左牵引变频器电流"
            "2045462782833665_1", //"左牵引变频器温度"
            "2045462782714881_1", //"左截割电流"
            "2045462782753793_1", //"左截割温度"
            "2045462777461761_1", //"滚筒温度1"

            "2045462781434881_1", //"右牵引变频器电流"
            "2045462781475841_1", //"右牵引变频器温度"
            "2045462781352961_1", //"右截割电流"
            "2045462781391873_1", //"右截割温度"
            "2045462777502721_1"  //"滚筒温度2"
        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            "info"=>[
                [
                    "label"=> "采煤机回路",
                    "state"=> ($baseData['2045462774273025_1'] ?? 0),
                    "text"=>($baseData['2045462774273025_1'] ?? 0) > 0 ? "启动" : "停止"
                ],
                [
                    "label"=> "1#液泵",
                    "state"=> ($baseData['2045462760791041_1'] ?? 0),
                    "text"=>($baseData['2045462760791041_1'] ?? 0) > 0 ? "启动" : "停止"
                ],
                [
                    "label"=> "2#液泵",
                    "state"=> ($baseData['2045462763287553_1'] ?? 0),
                    "text"=>($baseData['2045462763287553_1'] ?? 0) > 0 ? "启动" : "停止"
                ],
                [
                    "label"=> "3#液泵",
                    "state"=> ($baseData['2045462765548545_1'] ?? 0),
                    "text"=>($baseData['2045462765548545_1'] ?? 0) > 0 ? "启动" : "停止"
                ],
                [
                    "label"=> "1#水泵",
                    "state"=> ($baseData['2045462760676353_1'] ?? 0),
                    "text"=>($baseData['2045462760676353_1'] ?? 0) > 0 ? "启动" : "停止"
                ],
                [
                    "label"=> "2#水泵",
                    "state"=> ($baseData['2045462763166721_1'] ?? 0),
                    "text"=>($baseData['2045462763166721_1'] ?? 0) > 0 ? "启动" : "停止"
                ],
                [
                    "label"=> "纵撕",
                    "state"=> ($baseData['2045462782626817_1'] ?? 0) == 0 ? 1 : 0,
                    "text"=>($baseData['2045462782626817_1'] ?? 0) == 0 ? "正常" : "报警"
                ],
                [
                    "label"=> "烟雾",
                    "state"=> ($baseData['2045462781230081_1'] ?? 0) == 0 ? 1 : 0,
                    "text"=>($baseData['2045462781230081_1'] ?? 0) == 0 ? "正常" : "报警"
                ],
                [
                    "label"=> "堆煤",
                    "state"=> ($baseData['2045462774578177_1'] ?? 0) == 0 ? 1 : 0,
                    "text"=>($baseData['2045462774578177_1'] ?? 0) == 0 ? "正常" : "报警"
                ],
                [
                    "label"=> "通讯状态",
                    "state"=> ($baseData['2045462781189121_1'] ?? 0) == 0 ? 1 : 0,
                    "text"=>($baseData['2045462781189121_1'] ?? 0) == 0 ? "正常" : "异常"
                ],

            ],
            "table_data"=>[
                [
                    "title"=>"设备信息",
                    "thread"=>["参数名称", "数值"],
                    "tbody"=>[
                        [
                            "label"=>"煤机位置（架）",
                            "value"=>($baseData['2045462777732097_1'] ?? 0),
                        ],
                        [
                            "label"=>"牵引速度（m/min）",
                            "value"=>($baseData['2045462774410241_1'] ?? 0),
                        ],
                        [
                            "label"=>"俯仰角（°）",
                            "value"=>($baseData['2045462774860801_1'] ?? 0),
                        ],
                        [
                            "label"=>"倾角（°）",
                            "value"=>($baseData['2045462780767233_1'] ?? 0),
                        ],
                    ]
                ],
                [
                    "title"=>"采煤机基础信息",
                    "thread"=>["参数名称", "数值"],
                    "tbody"=>[
                        [
                            "label"=>"机身高度（mm）",
                            "value"=>1321,
                        ],
                        [
                            "label"=>"总装机功率（Kw）",
                            "value"=>1660,
                        ],
                        [
                            "label"=>"滚筒转速（r/min）",
                            "value"=>36.2,
                        ],
                        [
                            "label"=>"摇臂长度（mm）",
                            "value"=>32656,
                        ],
                        [
                            "label"=>"采高范围（m）",
                            "value"=>"1.9"-"3.7",
                        ],
                    ]
                ],
                [
                    "title"=>"工作面人员环境信息",
                    "thread"=>["参数名称", "数值"],
                    "tbody"=>[
                        [
                            "label"=>"220707回风巷15米",
                            "value"=>($baseData['2010296279116801_1'] ?? 0),
                        ],
                        [
                            "label"=>"220707回风巷80米",
                            "value"=>($baseData['2010796280116225_1'] ?? 0),
                        ],
                        [
                            "label"=>"220707机巷110米",
                            "value"=>($baseData['2019138663484417_1'] ?? 0),
                        ],
                        [
                            "label"=>"220707机巷1250米",
                            "value"=>($baseData['2019139795078145_1'] ?? 0),
                        ],
                    ]
                ],
                [
                    "title"=>"采煤机信息",
                    "thread"=>["参数名称", "数值"],
                    "tbody"=>[
                        [
                            "label"=>"左牵引电流(A)",
                            "value"=>($baseData['2045462782794753_1'] ?? 0),
                        ],
                        [
                            "label"=>"左牵引温度(℃)",
                            "value"=>($baseData['2045462782833665_1'] ?? 0),
                        ],
                        [
                            "label"=>"左截割电流(A)",
                            "value"=>($baseData['2045462782714881_1'] ?? 0),
                        ],
                        [
                            "label"=>"左截割温度(℃)",
                            "value"=>($baseData['2045462782753793_1'] ?? 0),
                        ],
                        [
                            "label"=>"左滚筒温度(℃)",
                            "value"=>($baseData['2045462777461761_1'] ?? 0),
                        ],

                        [
                            "label"=>"右牵引电流(A)",
                            "value"=>($baseData['2045462781434881_1'] ?? 0),
                        ],
                        [
                            "label"=>"右牵引温度(℃)",
                            "value"=>($baseData['2045462781475841_1'] ?? 0),
                        ],
                        [
                            "label"=>"右截割电流(A)",
                            "value"=>($baseData['2045462781352961_1'] ?? 0),
                        ],
                        [
                            "label"=>"右截割温度(℃)",
                            "value"=>($baseData['2045462781391873_1'] ?? 0),
                        ],
                        [
                            "label"=>"右滚筒温度(℃)",
                            "value"=>($baseData['2045462777502721_1'] ?? 0),
                        ],
                    ]
                ],
            ],
            "chartData_1"=>[
                "categories"=>[
                    "09/08", "09/09","09/10","09/11","09/12","09/13",
                ],
                "series"=>[
                    [
                        "name"=>"日产量",
                        "data"=>[1.3, 1.1, 1.2, 1.4, 1.5, 1.2]
                    ]
                ]
            ],
            "chartData_2"=>[
                "categories"=>[
                    "00:00", "00:00","00:00","00:00","00:00","00:00",
                ],
                "series"=>[
                    [
                        "name"=>"位置",
                        "data"=>[0, 0, 0, 0, 0, 0]
                    ]
                ]
            ]
        ];

        return json_encode($info);
    }

    /*
     * 三机
     * */
    public function getSjList() {

        $keys=[
            "2045462777420801_1",	//"枣泉煤矿220707工作面_刮板机运行状态"

            "2045462776265729_1",	//"枣泉煤矿220707工作面_刮板机头给定速度"
            "2045462776667137_1",	//"枣泉煤矿220707工作面_刮板机头直流母线电压"
            "2045462776486913_1",	//"枣泉煤矿220707工作面_刮板机头内腔湿度"
            "2045462776185857_1",	//"枣泉煤矿220707工作面_刮板机头电阻温度"
            "2045462776531969_1",	//"枣泉煤矿220707工作面_刮板机头逆变水冷板温度"
            "2045462776570881_1",	//"枣泉煤矿220707工作面_刮板机头腔体温度"
            "2045462776624129_1",	//"枣泉煤矿220707工作面_刮板机头整流侧水冷板温度"
            "2045462776224769_1",	//"枣泉煤矿220707工作面_刮板机头对地绝缘"
            "2045462776097793_1",	//"枣泉煤矿220707工作面_刮板机头电机转矩"
            "2045462776017921_1",	//"枣泉煤矿220707工作面_刮板机头电机电流"
            "2045462776142849_1",	//"枣泉煤矿220707工作面_刮板机头电机转速"
            "2045462776450049_1",	//"枣泉煤矿220707工作面_刮板机头减速器输入轴温度"
            "2045462776304641_1",	//"枣泉煤矿220707工作面_刮板机头减速器冷却水温度"
            "2045462776378369_1",	//"枣泉煤矿220707工作面_刮板机头减速器润滑油温度"
            "2045462776343553_1",	//"枣泉煤矿220707工作面_刮板机头减速器冷却水压力"
            "2045462775979009_1",	//"枣泉煤矿220707工作面_刮板机头电动机轴承温度"
            "2045462776056833_1",	//"枣泉煤矿220707工作面_刮板机头电机定子绕组温度"
            "2045462776413185_1",	//"枣泉煤矿220707工作面_刮板机头减速器润滑油油位"

            "2045462776986625_1",	//"枣泉煤矿220707工作面_刮板机尾给定速度"
            "2045462777377793_1",	//"枣泉煤矿220707工作面_刮板机尾直流母线电压"
            "2045462777218049_1",	//"枣泉煤矿220707工作面_刮板机尾内腔湿度"
            "2045462776914945_1",	//"枣泉煤矿220707工作面_刮板机尾电阻温度"
            "2045462777256961_1",	//"枣泉煤矿220707工作面_刮板机尾逆变水冷板温度"
            "2045462777297921_1",	//"枣泉煤矿220707工作面_刮板机尾腔体温度"
            "2045462777338881_1",	//"枣泉煤矿220707工作面_刮板机尾整流侧水冷板温度"
            "2045462776951809_1",	//"枣泉煤矿220707工作面_刮板机尾对地绝缘"
            "2045462776843265_1",	//"枣泉煤矿220707工作面_刮板机尾电机转矩"
            "2045462776767489_1",	//"枣泉煤矿220707工作面_刮板机尾电机电流"
            "2045462776880129_1",	//"枣泉煤矿220707工作面_刮板机尾电机转速"
            "2045462777177089_1",	//"枣泉煤矿220707工作面_刮板机尾减速器输入轴温度"
            "2045462777023489_1",	//"枣泉煤矿220707工作面_刮板机尾减速器冷却水温度"
            "2045462777103361_1",	//"枣泉煤矿220707工作面_刮板机尾减速器润滑油温度"
            "2045462777066497_1",	//"枣泉煤矿220707工作面_刮板机尾减速器冷却水压力"
            "2045462776724481_1",	//"枣泉煤矿220707工作面_刮板机尾电动机轴承温度"
            "2045462776804353_1",	//"枣泉煤矿220707工作面_刮板机尾电机定子绕组温度"
            "2045462777140225_1",	//"枣泉煤矿220707工作面_刮板机尾减速器润滑油油位"

            "2045462780288001_1",	//"枣泉煤矿220707工作面_破碎机隔离开关合闸状态"
            "2045462780249089_1",	//"枣泉煤矿220707工作面_破碎机隔离开关电压"
            "2045462780371969_1",	//"枣泉煤矿220707工作面_破碎机回路启停状态"
            "2045462780331009_1",	//"枣泉煤矿220707工作面_破碎机回路电流"

            "2045462774193153_1",	//"枣泉煤矿220707工作面_采煤机隔离开关合闸状态"
            "2045462774154241_1",	//"枣泉煤矿220707工作面_采煤机隔离开关电压"
            "2045462774273025_1",	//"枣泉煤矿220707工作面_采煤机回路启停状态"
            "2045462774230017_1",	//"枣泉煤矿220707工作面_采煤机回路电流"

            "2045462780623873_1",	//"枣泉煤矿220707工作面_破碎机减速器输入轴温度"
            "2045462780410881_1",	//"枣泉煤矿220707工作面_破碎机减速器冷却水温度"
            "2045462780523521_1",	//"枣泉煤矿220707工作面_破碎机减速器润滑油温度"
            "2045462780474369_1",	//"枣泉煤矿220707工作面_破碎机减速器冷却水压力"
            "2045462780163073_1",	//"枣泉煤矿220707工作面_破碎机电动机轴承温度"
            "2045462780199937_1",	//"枣泉煤矿220707工作面_破碎机电机定子绕组温度"
            "2045462780566529_1",	//"枣泉煤矿220707工作面_破碎机减速器润滑油油位"

            "2045462780728321_1",	//"枣泉煤矿220707工作面_破碎机运行状态"

            "2045462782241793_1",	//"枣泉煤矿220707工作面_转载机运行状态"
            "2045462781852673_1",	//"枣泉煤矿220707工作面_转载机给定速度"
            "2045462782321665_1",	//"枣泉煤矿220707工作面_转载机直流母线电压"
            "2045462782088193_1",	//"枣泉煤矿220707工作面_转载机内腔湿度"
            "2045462781772801_1",	//"枣泉煤矿220707工作面_转载机电阻温度"
            "2045462782127105_1",	//"枣泉煤矿220707工作面_转载机逆变水冷板温度"
            "2045462782163969_1",	//"枣泉煤矿220707工作面_转载机腔体温度"
            "2045462782282753_1",	//"枣泉煤矿220707工作面_转载机整流侧水冷板温度"
            "2045462781811713_1",	//"枣泉煤矿220707工作面_转载机对地绝缘"
            "2045462781694977_1",	//"枣泉煤矿220707工作面_转载机电机转矩"
            "2045462781619201_1",	//"枣泉煤矿220707工作面_转载机电机电流"
            "2045462781733889_1",	//"枣泉煤矿220707工作面_转载机电机转速"
            "2045462782049281_1",	//"枣泉煤矿220707工作面_转载机减速器输入轴温度"
            "2045462781893633_1",	//"枣泉煤矿220707工作面_转载机减速器冷却水温度"
            "2045462781969409_1",	//"枣泉煤矿220707工作面_转载机减速器润滑油温度"
            "2045462781932545_1",	//"枣泉煤矿220707工作面_转载机减速器冷却水压力"
            "2045462781582337_1",	//"枣泉煤矿220707工作面_转载机电动机轴承温度"
            "2045462781658113_1",	//"枣泉煤矿220707工作面_转载机电机定子绕组温度"
            "2045462782010369_1",	//"枣泉煤矿220707工作面_转载机减速器润滑油油位"

        ];

        // 获取点位数据
        $baseData = $this->apiService->postPointRealData($this->apiUrl, $keys)['data'];


        $info = [
            [
                "label"=>"转载机设备信息",
                "state"=> ($baseData['2045462782241793_1'] ?? 0) > 0 ? 1 : 0,
                "text"=>($baseData['2045462782241793_1'] ?? 0) > 0 ? "启动" : "停止",
                "table"=>[
                    [
                        "title"=>"转载机设备信息",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "给定速度",
                                "value"=> ($baseData['2045462781852673_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "直流母线电压",
                                "value"=> ($baseData['2045462782321665_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "内腔湿度",
                                "value"=> ($baseData['2045462782088193_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电阻温度",
                                "value"=> ($baseData['2045462781772801_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "逆变水冷板温度",
                                "value"=> ($baseData['2045462782127105_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "腔体温度",
                                "value"=> ($baseData['2045462782163969_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "整流侧水冷板温度",
                                "value"=> ($baseData['2045462782282753_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "对地绝缘",
                                "value"=> ($baseData['2045462781811713_1'] ?? 0)." MΩ",
                            ],
                            [
                                "label"=> "电机转柜",
                                "value"=> ($baseData['2045462781694977_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电机电流",
                                "value"=> ($baseData['2045462781619201_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "电机转速",
                                "value"=> ($baseData['2045462781733889_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462782049281_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462781893633_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462781969409_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462781932545_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462781582337_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462781658113_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462782010369_1'] ?? 0)." m",
                            ],
                        ]
                    ]
                ]
            ],
            [
                "label"=>"采煤机破碎机设备信息",
                "state"=> ($baseData['2045462780728321_1'] ?? 0) > 0 ? 1 : 0,
                "text"=>($baseData['2045462780728321_1'] ?? 0) > 0 ? "启动" : "停止",
                "table"=>[
                    [
                        "title"=>"采煤机破碎机设备信息",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "破碎机隔离开关状态",
                                "value"=> ($baseData['2045462780288001_1'] ?? 0) > 0 ? "合闸" : "分闸",
                            ],
                            [
                                "label"=> "破碎机隔离开关电压",
                                "value"=> ($baseData['2045462780249089_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "破碎机回路启停状态",
                                "value"=> ($baseData['2045462780371969_1'] ?? 0) > 0 ? "启动" : "停止",
                            ],
                            [
                                "label"=> "破碎机回路电流",
                                "value"=> ($baseData['2045462780331009_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "采煤机隔离开关合闸状态",
                                "value"=> ($baseData['2045462774193153_1'] ?? 0) > 0 ? "合闸" : "分闸",
                            ],
                            [
                                "label"=> "采煤机隔离开关电压",
                                "value"=> ($baseData['2045462774154241_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "采煤机回路启停状态",
                                "value"=> ($baseData['2045462774273025_1'] ?? 0) > 0 ? "启动" : "停止",
                            ],
                            [
                                "label"=> "采煤机回路电流",
                                "value"=> ($baseData['2045462774230017_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462780623873_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462780410881_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462780523521_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462780474369_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462780163073_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462780199937_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462780566529_1'] ?? 0)." m",
                            ],
                        ]
                    ]
                ]
            ],
            [
                "label"=>"刮板机设备信息",
                "state"=> ($baseData['2045462777420801_1'] ?? 0) > 0 ? 1 : 0,
                "text"=>($baseData['2045462777420801_1'] ?? 0) > 0 ? "启动" : "停止",
                "table"=>[
                    [
                        "title"=>"刮板机设备信息-机头",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "给定速度",
                                "value"=> ($baseData['2045462776265729_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "直流母线电压",
                                "value"=> ($baseData['2045462776667137_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "内腔湿度",
                                "value"=> ($baseData['2045462776486913_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电阻温度",
                                "value"=> ($baseData['2045462776185857_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "逆变水冷板温度",
                                "value"=> ($baseData['2045462776531969_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "腔体温度",
                                "value"=> ($baseData['2045462776570881_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "整流侧水冷板温度",
                                "value"=> ($baseData['2045462776624129_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "对地绝缘",
                                "value"=> ($baseData['2045462776224769_1'] ?? 0)." MΩ",
                            ],
                            [
                                "label"=> "电机转柜",
                                "value"=> ($baseData['2045462776097793_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电机电流",
                                "value"=> ($baseData['2045462776017921_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "电机转速",
                                "value"=> ($baseData['2045462776142849_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462776450049_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462776304641_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462776378369_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462776343553_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462775979009_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462776056833_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462776413185_1'] ?? 0)." m",
                            ],
                        ]
                    ],
                    [
                        "title"=>"刮板机设备信息-机尾",
                        "thead"=>["参数名称", "数值"],
                        "tbody"=>[
                            [
                                "label"=> "给定速度",
                                "value"=> ($baseData['2045462776986625_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "直流母线电压",
                                "value"=> ($baseData['2045462777377793_1'] ?? 0)." V",
                            ],
                            [
                                "label"=> "内腔湿度",
                                "value"=> ($baseData['2045462777218049_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电阻温度",
                                "value"=> ($baseData['2045462776914945_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "逆变水冷板温度",
                                "value"=> ($baseData['2045462777256961_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "腔体温度",
                                "value"=> ($baseData['2045462777297921_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "整流侧水冷板温度",
                                "value"=> ($baseData['2045462777338881_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "对地绝缘",
                                "value"=> ($baseData['2045462776951809_1'] ?? 0)." MΩ",
                            ],
                            [
                                "label"=> "电机转柜",
                                "value"=> ($baseData['2045462776843265_1'] ?? 0)." %",
                            ],
                            [
                                "label"=> "电机电流",
                                "value"=> ($baseData['2045462776767489_1'] ?? 0)." A",
                            ],
                            [
                                "label"=> "电机转速",
                                "value"=> ($baseData['2045462776880129_1'] ?? 0)." RPM",
                            ],
                            [
                                "label"=> "减速器输入轴温度",
                                "value"=> ($baseData['2045462777177089_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水温度",
                                "value"=> ($baseData['2045462777023489_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油温度",
                                "value"=> ($baseData['2045462777103361_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器冷却水压力",
                                "value"=> ($baseData['2045462777066497_1'] ?? 0)." Mpa",
                            ],
                            [
                                "label"=> "电动机轴承温度",
                                "value"=> ($baseData['2045462776724481_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "电机定子绕组温度",
                                "value"=> ($baseData['2045462776804353_1'] ?? 0)." ℃",
                            ],
                            [
                                "label"=> "减速器润滑油油位",
                                "value"=> ($baseData['2045462777140225_1'] ?? 0)." m",
                            ],
                        ]
                    ],
                ]
            ],
        ];

        return json_encode($info);
    }


}
